#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
# Copyright (C) 2021  Jeronimo Wiederhold <jeronimo.wiederhold@sva.de>
#                     for SVA System Vertrieb Alexander GmbH

# Example output
"""
<name>|<status>
<<<hpe_oneview_fabrics:sep(124)>>>
DefaultFabric|OK
"""

from .agent_based_api.v1 import *

info_list = ["name", "status"]
state_map = {
    0: State.OK,
    1: State.WARN,
    2: State.CRIT,
    3: State.UNKNOWN
}

def parse_hpe_oneview_fabrics(string_table):
    output = []
    for interconnect in string_table:
        info_map = dict(zip(info_list, interconnect))
        output.append(info_map)
    return output

register.agent_section(
    name="hpe_oneview_fabrics",
    parse_function=parse_hpe_oneview_fabrics
)

def discovery_hpe_oneview_fabrics(section):
    for interconnect in section:
        yield Service(item=interconnect["name"])


def check_hpe_oneview_fabrics(item, params, section):
    map_status = params["map_status"]

    for interconnect in section:
        if interconnect["name"] == item:

            s= state_map[map_status[interconnect["status"]]] 
            yield Result(state=s, summary="Status: {}".format(interconnect["status"]))





register.check_plugin(
    name="hpe_oneview_fabrics",
    service_name="Fabrics %s",
    check_ruleset_name="hpe_oneview_fabrics",
    check_default_parameters={
        "map_status": {
            "OK": 0,
            "Disabled": 1,
            "Warning": 1,
            "Critical": 2,
            "Unknown": 3
            }},
    discovery_function=discovery_hpe_oneview_fabrics,
    check_function=check_hpe_oneview_fabrics,
)