#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
# Copyright (C) 2021  Jeronimo Wiederhold <jeronimo.wiederhold@sva.de>
#                     for SVA System Vertrieb Alexander GmbH

# Example output
"""
<count>
<created>|<description>|<uri> of last event
<<<hpe_oneview_locked_alerts:sep(124)>>>
16
2021-07-08T09:11:14.769Z|The connection on downlink port 27, subport c has failed. The subport is unlinked.|/rest/interconnects/d45f3dc0-fe1c-46c7-98c5-c021878dd26d
"""

from .agent_based_api.v1 import *
from datetime import datetime



def discovery_hpe_oneview_locked_alerts(section):
    if section is not []:
        yield Service()


def check_hpe_oneview_locked_alerts(section):
    count = section[0][0]
    summary = "No Active Alerts"
    message = " "

    try:
        created = datetime.strptime(section[1][0], "%Y-%m-%dT%H:%M:%S.%fZ").strftime("%d.%m.%Y at %H:%M:%S")
        message = section[1][1].replace("\{", "{").replace("\}", "}")
        summary= "Total Locked Alerts: {}, last Alert received: {}, Click for details".format(count, created)
    except:
        pass


    s = State.OK
    if int(count) > 0:
        s = State.CRIT
    
    
    yield Result(state=s, summary=summary, details=message)


register.check_plugin(
    name="hpe_oneview_locked_alerts",
    service_name="Locked Alerts",
    discovery_function=discovery_hpe_oneview_locked_alerts,
    check_function=check_hpe_oneview_locked_alerts,
)
