#!/usr/bin/python
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
# Copyright (C) 2020  Jeronimo Wiederhold <jeronimo.wiederhold@sva.de>
#                     for SVA System Vertrieb Alexander GmbH

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    Integer,
    Tuple,
    MonitoringState
)

from cmk.gui.plugins.wato import (
    CheckParameterRulespecWithoutItem,
    rulespec_registry,
    RulespecGroupCheckParametersApplications,
)


def _parameter_valuespec_hpe_oneview_ca():
    return Dictionary(elements=[
        ("map_certStatus",
         Dictionary(
             title=_("Map Attribute 'certStatus'"),
             elements=[
                 ("ABOUTTOEXPIRE", MonitoringState(title=_("ABOUTTOEXPIRE"), default_value=1)),
                 ("BAD", MonitoringState(title=_("BAD"), default_value=2)),
                 ("CONFLICT", MonitoringState(title=_("CONFLICT"), default_value=2)),
                 ("CRL_EXPIRED", MonitoringState(title=_("CRL_EXPIRED"), default_value=2)),
                 ("CRL_INVALID", MonitoringState(title=_("CRL_INVALID"), default_value=2)),
                 ("CRL_NOT_FOUND", MonitoringState(title=_("CRL_NOT_FOUND"), default_value=2)),
                 ("CRL_NOT_LOADED", MonitoringState(title=_("CRL_NOT_LOADED"), default_value=2)),
                 ("CRL_VERIFICATION_FAILED", MonitoringState(title=_("CRL_VERIFICATION_FAILED"), default_value=2)),
                 ("GOOD", MonitoringState(title=_("GOOD"), default_value=0)),
                 ("INVALID", MonitoringState(title=_("INVALID"), default_value=2)),
                 ("INVALID_CERTPATH", MonitoringState(title=_("INVALID_CERTPATH"), default_value=2)),
                 ("KEY_STORE_NOT_FOUND", MonitoringState(title=_("KEY_STORE_NOT_FOUND"), default_value=2)),
                 ("NA", MonitoringState(title=_("NA"), default_value=1)),
                 ("NOT_TRUSTED", MonitoringState(title=_("NOT_TRUSTED"), default_value=1)),
                 ("PARSING_FAILED", MonitoringState(title=_("PARSING_FAILED"), default_value=2)),
                 ("REVOCATION_CHECK_NOT_DONE", MonitoringState(title=_("REVOCATION_CHECK_NOT_DONE"), default_value=1)),
                 ("REVOKED", MonitoringState(title=_("REVOKED"), default_value=2)),
                 ("SUSPENDED", MonitoringState(title=_("SUSPENDED"), default_value=2)),
             ],
             optional_keys=False,
         )),
    ],)

rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name="hpe_oneview_ca",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_hpe_oneview_ca,
        title=lambda: _("HPE OneView CA Status"),
    ))
